Imports System.Math

Module PublicVars

	'MapPoint Web Service credentials. Replace the following placeholders
	'with credentials provided in your MapPoint evaluation agreement or subscription
	'and add a Web reference named MP
	Public Const strMPUserID As String = "Your MapPoint UserID"
	Public Const strMPPassword As String = "Your MapPoint Password"

	'Variables and procedures common to multiple classes
	'Image data for ImageData.vb
	Public frmImageData As Form = New ImageData
	Public frmPlaces As Form = New PlaceList
	Public frmLandmarks As Form = New LandMarks
	Public frmAddress As Form = New AddressMP
	Public frmAbout As Form = New AboutMP
	Public intTiles As Integer
	Public dblLonPoint As Double
	Public dblLatPoint As Double
	Public dblLonNW As Double
	Public dblLatNW As Double
	Public dblLonSE As Double
	Public dblLatSE As Double
	Public dblTileDistX As Double
	Public dblTileDistY As Double
	Public dblImageDistX As Double
	Public dblImageDistY As Double
	Public intImageBytes As Integer
	Public intImageBase64 As Integer
	Public strPixFormat As String
	Public strRawFormat As String
	Public intOffsetX As Integer
	Public intOffsetY As Integer
	Public datEarliestTile As DateTime = DateTime.Today
	Public datLatestTile As DateTime = DateTime.Today
	Public lngGetImageTime As Long
	Public strDescPhoto As String
	Public strDescTopo As String
	Public strProjPhoto As String
	Public strProjTopo As String
	Public strAddress As String

	'City and state names/abbreviations
	Public strCity As String
	Public strState As String

	'Control vars for Places and Landmarks lists and Address dialog
	Public blnEnterPlace As Boolean
	Public blnIsFromPlaces As Boolean
	Public blnIsFromLandmarks As Boolean
	Public blnIsFromAddress As Boolean

	'********************************************
	'Calculate North-South and East-West Tile Distance
	'from latitude and longitude
	'There are several versions of this calculation
	'This example uses the haversine version
	'********************************************

	Public Function GetDistanceKm(ByVal dblLat1 As Double, ByVal dblLon1 As Double, ByVal dblLat2 As Double, ByVal dblLon2 As Double) As Double
		'Calculate the distance between two points on the globe
		'Argument values are decimal latitude and longitude degrees
		Dim dblLonDiff As Double
		Dim dblDist As Double
		dblLonDiff = dblLon1 - dblLon2
		dblDist = Sin(DegreesToRadians(dblLat1)) * Sin(DegreesToRadians(dblLat2)) + _
		 Cos(DegreesToRadians(dblLat1)) * Cos(DegreesToRadians(dblLat2)) * _
		 Cos(DegreesToRadians(dblLonDiff))
		dblDist = Acos(dblDist)
		dblDist = RadiansToDegrees(dblDist)
		'In miles
		dblDist = dblDist * 60 * 1.1515
		'In km
		Return dblDist * 1.609344
	End Function

	Function DegreesToRadians(ByVal deg As Double) As Double
		'Convert decimal degrees to radians
		Return CDbl(deg * PI / 180)
	End Function

	Function RadiansToDegrees(ByVal rad As Double) As Double
		'Convert radians to decimal degrees
		Return CDbl(rad * 180 / PI)
	End Function

	Public Function CalculateImageDist(ByVal dblTileDist As Double, ByVal strAxis As String) As Double
		'Calculate image X and Y distances in km
		Dim dblDist As Double
		Dim intTilePixels As Integer
		Select Case intTiles
			Case 12
				'4 by 3 tiles
				If strAxis = "X" Then
					intTilePixels = 4 * 200
				Else
					intTilePixels = 3 * 200
				End If
			Case 15
				'5 by 3 tiles
				If strAxis = "X" Then
					intTilePixels = 5 * 200
				Else
					intTilePixels = 3 * 200
				End If
			Case 16
				'4 by 4 tiles
				If strAxis = "X" Then
					intTilePixels = 4 * 200
				Else
					intTilePixels = 4 * 200
				End If
			Case 20
				'5 by 4 tiles
				If strAxis = "X" Then
					intTilePixels = 5 * 200
				Else
					intTilePixels = 4 * 200
				End If
		End Select
		If strAxis = "X" Then
			dblDist = dblTileDist * 640 / intTilePixels
		Else
			dblDist = dblTileDist * 480 / intTilePixels
		End If
		Return dblDist
	End Function

	Public Sub AbbreviateState()
		'Case statement imported from USPS abbreviations
		Select Case UCase(strState)
			Case "ALABAMA"
				strState = "AL"
			Case "ALASKA"
				strState = "AK"
			Case "AMERICAN SAMOA"
				strState = "AS"
			Case "ARIZONA"
				strState = "AZ"
			Case "ARKANSAS"
				strState = "AR"
			Case "CALIFORNIA"
				strState = "CA"
			Case "COLORADO"
				strState = "CO"
			Case "CONNECTICUT"
				strState = "CT"
			Case "DELAWARE"
				strState = "DE"
			Case "DISTRICT OF COLUMBIA"
				strState = "DC"
			Case "FEDERATED STATES OF MICRONESIA"
				strState = "FM"
			Case "FLORIDA"
				strState = "FL"
			Case "GEORGIA"
				strState = "GA"
			Case "GUAM"
				strState = "GU"
			Case "HAWAII"
				strState = "HI"
			Case "IDAHO"
				strState = "ID"
			Case "ILLINOIS"
				strState = "IL"
			Case "INDIANA"
				strState = "IN"
			Case "IOWA"
				strState = "IA"
			Case "KANSAS"
				strState = "KS"
			Case "KENTUCKY"
				strState = "KY"
			Case "LOUISIANA"
				strState = "LA"
			Case "MAINE"
				strState = "ME"
			Case "MARSHALL ISLANDS"
				strState = "MH"
			Case "MARYLAND"
				strState = "MD"
			Case "MASSACHUSETTS"
				strState = "MA"
			Case "MICHIGAN"
				strState = "MI"
			Case "MINNESOTA"
				strState = "MN"
			Case "MISSISSIPPI"
				strState = "MS"
			Case "MISSOURI"
				strState = "MO"
			Case "MONTANA"
				strState = "MT"
			Case "NEBRASKA"
				strState = "NE"
			Case "NEVADA"
				strState = "NV"
			Case "NEW HAMPSHIRE"
				strState = "NH"
			Case "NEW JERSEY"
				strState = "NJ"
			Case "NEW MEXICO"
				strState = "NM"
			Case "NEW YORK"
				strState = "NY"
			Case "NORTH CAROLINA"
				strState = "NC"
			Case "NORTH DAKOTA"
				strState = "ND"
			Case "NORTHERN MARIANA ISLANDS"
				strState = "MP"
			Case "OHIO"
				strState = "OH"
			Case "OKLAHOMA"
				strState = "OK"
			Case "OREGON"
				strState = "OR"
			Case "PALAU"
				strState = "PW"
			Case "PENNSYLVANIA"
				strState = "PA"
			Case "PUERTO RICO"
				strState = "PR"
			Case "RHODE ISLAND"
				strState = "RI"
			Case "SOUTH CAROLINA"
				strState = "SC"
			Case "SOUTH DAKOTA"
				strState = "SD"
			Case "TENNESSEE"
				strState = "TN"
			Case "TEXAS"
				strState = "TX"
			Case "UTAH"
				strState = "UT"
			Case "VERMONT"
				strState = "VT"
			Case "VIRGIN ISLANDS"
				strState = "VI"
			Case "VIRGINIA "
				strState = "VA"
			Case "WASHINGTON"
				strState = "WA"
			Case "WEST VIRGINIA"
				strState = "WV"
			Case "WISCONSIN"
				strState = "WI"
			Case "WYOMING"
				strState = "WY"
		End Select
	End Sub
End Module
